| Title: | All-in-One Chi Distribution CI |
|---|---|
| Description: | Computes confidence intervals for variance using the Chi-Square distribution, without requiring raw data. Wikipedia (2025) <https://en.wikipedia.org/wiki/Chi-squared_distribution>. 'All-in-One Chi Distribution CI' provides functions to calculate confidence intervals for the population variance based on a chi-squared distribution, utilizing a sample variance and sample size. It offers only a simple all-in-one method for quick calculations to find the CI for Chi Distribution. |
| Authors: | David Reese [aut, cre] |
| Maintainer: | David Reese <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.1.1 |
| Built: | 2026-06-08 08:54:25 UTC |
| Source: | https://github.com/cran/StatTools |
This function calculates the confidence interval for variance when only + the sample variance and sample size are known.
chi_var_ci_no_data(s2_given, n_given, conf_level)chi_var_ci_no_data(s2_given, n_given, conf_level)
s2_given |
Numeric. The sample variance. |
n_given |
Integer. The sample size. |
conf_level |
Numeric. The confidence level (e.g., 0.95 for 95% CI). |
A numeric vector with the lower and upper bounds of the confidence interval.
s2_given <- 21.5 # Sample variance n_given <- 26 # Sample size conf_level <- 0.98 # 98% confidence level chi_var_ci_no_data(s2_given, n_given, conf_level)s2_given <- 21.5 # Sample variance n_given <- 26 # Sample size conf_level <- 0.98 # 98% confidence level chi_var_ci_no_data(s2_given, n_given, conf_level)